@@ -16,16 +16,22 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
-#include "../config.h"
-#include "gnome_chess.h"
-#include "makros.h"
-#include "position.h"
-#include "pro.h"
-#include "pgn.h"
- 
-struct engine *first_chess_programm;
+#include <config.h>
+#include <gnome.h>
+#include <glade/glade.h>
+#ifdef USE_WM_ICONS
+#include <libgnomeui/gnome-window-icon.h>
+#endif
 
-GtkWidget *app;
+#include "debug.h"
+#include "makros.h"
+#include "prefs.h"
+#include "engine_local.h"
+#include "engine_ics.h"
+#include "engine-pgn.h"
+#include "board-window.h"
+ 
+/* Command line variables */
 static gint *ics = 0;
 static char *icshost = NULL;
 static char *icsuser = NULL;
@@ -41,7 +47,7 @@ static const struct poptOption gnome_chess_popt_options [] = {
 	{ "debug", '\0', POPT_ARG_INT, &debug, 0,
 	  N_("Enables some debugging functions"), N_("LEVEL") },
 	{ "fcp", '\0', POPT_ARG_STRING, &fcp, 0,
-	  N_("First Chess Programm"),   N_("FILE") },
+	  N_("First Chess Program"),   N_("PROGRAM") },
 	{ "ics", '\0', POPT_ARG_NONE, &ics, 0,
 	  N_("Start in ICS mode"), NULL },
 	{ "icshost", '\0', POPT_ARG_STRING, &icshost, 0,
@@ -58,61 +64,58 @@ static const struct poptOption gnome_chess_popt_options [] = {
 	{ NULL, '\0', 0, NULL, 0 }
 };
 
-int main(int argc,char *argv[]) {
-	GtkWidget *box;
+GtkWidget *main_board_window = NULL;
 
+int 
+main(int argc,char *argv[]) 
+{
+	GtkObject *engine;
+	GtkWidget *view;
+	int i = 0;
+	
+	/* Internationalization */
 	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
 	textdomain (PACKAGE);
 
-	gnome_init_with_popt_table ("Gnome Chess", VERSION, 
-			argc, argv, gnome_chess_popt_options,0, &ctx);
-
-	/* Initialize the position and build a new board */
-	currPositionPtr = gnomechess_position_new_initial();
-	box = gnomechess_board_new();
+	/* Command Line Args */
+	gnome_init_with_popt_table ("Gnome Chess", 
+				    VERSION, 
+				    argc, argv, 
+				    gnome_chess_popt_options,
+				    0, &ctx);
 
+#ifdef USE_WM_ICONS
+	gnome_window_icon_set_default_from_file (GNOME_ICONDIR 
+						 "/gnome-chess.png");
+#endif
 	/* Initialize the preferences */
-	gnomechess_prefs_init();
+	prefs_init();
 
-	/* Build the app framework */
-	app = gnome_app_new ("gnome-chess", _("Gnome Chess"));
-	create_menus();
-	gnome_app_set_contents ( GNOME_APP (app), box);
-	gtk_widget_show(box);
-	gtk_widget_show (app);
+	/* Initialize glade */
+	glade_gnome_init();
 
-	/* Ugly hack to get rid of a temporary zvt problem */
-	gtk_widget_queue_resize(board.messages);
+	main_board_window = board_window_new ();
+	gtk_widget_show (main_board_window);
 
-	first_chess_programm = NULL;
-	/* Check to see if we got command line args for an engine */
-	if (ics) {
- 		first_chess_programm = engine_ics_new(icshost, icsuser, icspass, icsport, icstelnetprogram);
-	} else if (fcp) {
-		first_chess_programm = engine_local_new(fcp,NULL);
-	} else {
-		gchar *cmd;
-		cmd = gnome_is_program_in_path("crafty");
-		if (cmd)
-			first_chess_programm = engine_local_new(cmd,"xboard");
-	  	else {
-			cmd = gnome_is_program_in_path("gnuchessx");
-			if (cmd)
-				first_chess_programm = engine_local_new(cmd,NULL);
-		}
+	if (fcp != NULL) {
+		engine = engine_local_new (fcp, NULL);
+		view = game_view_new_with_engine (ENGINE (engine));
+		board_window_add_view (BOARD_WINDOW (main_board_window), 
+				       GAME_VIEW (view));
 	}
 
-	/* if no valid engine so far was found, we use a null engine. */
-	if (first_chess_programm == NULL)
-		first_chess_programm = engine_null_new(NULL,NULL);
+	if (ics && icshost != NULL)
+		engine = engine_ics_new (icshost, icsport, icsuser, icspass, NULL);
 
-	/* Check to see if we got command line args for any pgn files */
-	startup_files = poptGetArgs (ctx);
-	if (startup_files) 
-		pgn_open(*startup_files);
+	/* open the files */
+	startup_files = (char **)poptGetArgs (ctx);
+	for (i = 0; startup_files && startup_files[i]; i++)
+		engine_pgn_new (startup_files[i]);
 	poptFreeContext (ctx);
-
+	
+	/* Begin the event loop */
 	gtk_main ();
+
 	return 0;
 }
 
