@@ -19,21 +19,33 @@
 #ifndef TIMER_H
 #define TIMER_H
 
-extern int debug;        
+#include <gtk/gtk.h>
 
-typedef struct {
-	int sec;
+#define TIMER(obj)	GTK_CHECK_CAST (obj, timer_get_type(), Timer)
+#define TIMER_CLASS(klass)  GTK_CHECK_CLASS_CAST (klass, timer_get_type(), TimerClass)
+#define IS_TIMER(obj)       GTK_CHECK_TYPE (obj, timer_get_type())
+
+typedef struct _Timer       Timer;
+typedef struct _TimerClass  TimerClass;
+
+struct _TimerClass {
+	GtkLabelClass parent_class;
+
+	void (*expired) (Timer *timer);
+};
+
+struct _Timer {
+	GtkLabel label;
+
+	gint sec;
 	guint handlerid;
-	GtkWidget *label;
-} timer;
+};
 
-timer* gnomechess_timer_new(void);
-timer* gnomechess_timer_new_time(int sec);
-void gnomechess_timer_callback(gpointer data);
-void gnomechess_timer_set(timer *tmr, int sec);
-void gnomechess_timer_start(timer *tmr);
-void gnomechess_timer_stop(timer *tmr);
-GtkWidget* gnomechess_timer_getview(timer *tmr);
-void gnomechess_timer_destroy(timer *tmr);
+GtkType timer_get_type (void);
+GtkWidget* timer_new (gint secs);
+gint timer_get(Timer *timer);
+void timer_set(Timer *timer, gint secs);
+void timer_start(Timer *timer);
+void timer_stop(Timer *timer);
 
-#endif
\ No newline at end of file
+#endif
